@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 from fabric.tasks import WrappedCallableTask as _WrappedCallableTask
 
 
@@ -14,7 +12,7 @@ class WrappedCallableTask(_WrappedCallableTask):
 
     def __init__(self, *args, **kwargs):
         real_module = kwargs.pop('real_module', None)
-        super(WrappedCallableTask, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if real_module:
             self.__module__ = real_module
 
